import { SpaceGraphCustomAttributeJson } from '@archilogic/space-graph-core';
export type DisplayMode = 'color' | 'text' | 'shape';
export interface Range {
    min: number | null;
    max: number | null;
}
export interface ShapeRadiusRange {
    min: number;
    max: number;
}
export interface OpacityRange {
    min: number;
    max: number;
}
export type RangeType = 'min' | 'max';
export interface State {
    selectedAttributeIds: string[];
    customRanges: Record<string, Range>;
    colors: Record<string, string>;
    defaultOpacities: Record<string, number>;
    displayModes: Record<string, DisplayMode>;
    textFormats: Record<string, string>;
    shapeRadiusRanges: Record<string, ShapeRadiusRange>;
    textSizes: Record<string, number>;
    opacityRanges: Record<string, OpacityRange>;
}
export declare const defaults: {
    readonly textSize: 32;
    readonly shapeRadius: {
        readonly min: 0.2;
        readonly max: 1;
    };
    readonly opacity: {
        readonly boolean: 0.4;
        readonly default: 1;
        readonly numeric: {
            readonly min: 0.2;
            readonly max: 1;
        };
    };
};
export declare const state: {
    selectedAttributeIds: string[];
    customRanges: Record<string, Range>;
    colors: Record<string, string>;
    defaultOpacities: Record<string, number>;
    displayModes: Record<string, DisplayMode>;
    textFormats: Record<string, string>;
    shapeRadiusRanges: Record<string, ShapeRadiusRange>;
    textSizes: Record<string, number>;
    opacityRanges: Record<string, OpacityRange>;
};
export declare function getRangeValue(attrId: string, type: RangeType, valueRange: {
    minValue: number;
    maxValue: number;
} | null): number;
export declare function setRangeValue(attrId: string, type: RangeType, value: string | null): void;
export declare function getCustomColor(attrId: string): string;
export declare function setCustomColor(attrId: string, color: string): void;
export declare function getDefaultOpacity(attr: SpaceGraphCustomAttributeJson): number;
export declare function setDefaultOpacity(attrId: string, opacity: number): void;
export declare function getDisplayMode(attrId: string): DisplayMode;
export declare function setDisplayMode(attrId: string, mode: DisplayMode): void;
export declare function getTextFormat(attrId: string): string;
export declare function setTextFormat(attrId: string, format: string): void;
export declare function getShapeRadiusRange(attrId: string): ShapeRadiusRange;
export declare function setShapeRadiusRange(attrId: string, type: RangeType, value: number): void;
export declare function getTextSize(attrId: string): number;
export declare function setTextSize(attrId: string, size: number): void;
export declare function getOpacityRange(attrId: string): OpacityRange;
export declare function setOpacityRange(attrId: string, key: keyof OpacityRange, value: number): void;
